# mr-openapi
REST API for Model Registry to create and manage ML model metadata

The `mr_openapi` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1alpha3
- Package version: 1.0.0
- Generator version: 7.6.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil
* aiohttp
* pydantic

## Getting Started

In your own code, to use this library to connect and interact with mr-openapi,
you can run the following:

```python

import mr_openapi
from mr_openapi.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://localhost:8080
# See configuration.py for a list of all supported configuration parameters.
configuration = mr_openapi.Configuration(
    host = "https://localhost:8080"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): Bearer
configuration = mr_openapi.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
async with mr_openapi.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = mr_openapi.ModelRegistryServiceApi(api_client)
    servingenvironment_id = 'servingenvironment_id_example' # str | A unique identifier for a `ServingEnvironment`.
    inference_service_create = mr_openapi.InferenceServiceCreate() # InferenceServiceCreate | A new `InferenceService` to be created.

    try:
        # Create a InferenceService in ServingEnvironment
        api_response = await api_instance.create_environment_inference_service(servingenvironment_id, inference_service_create)
        print("The response of ModelRegistryServiceApi->create_environment_inference_service:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ModelRegistryServiceApi->create_environment_inference_service: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:8080*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ModelRegistryServiceApi* | [**create_environment_inference_service**](mr_openapi/docs/ModelRegistryServiceApi.md#create_environment_inference_service) | **POST** /api/model_registry/v1alpha3/serving_environments/{servingenvironmentId}/inference_services | Create a InferenceService in ServingEnvironment
*ModelRegistryServiceApi* | [**create_inference_service**](mr_openapi/docs/ModelRegistryServiceApi.md#create_inference_service) | **POST** /api/model_registry/v1alpha3/inference_services | Create a InferenceService
*ModelRegistryServiceApi* | [**create_inference_service_serve**](mr_openapi/docs/ModelRegistryServiceApi.md#create_inference_service_serve) | **POST** /api/model_registry/v1alpha3/inference_services/{inferenceserviceId}/serves | Create a ServeModel action in a InferenceService
*ModelRegistryServiceApi* | [**create_model_artifact**](mr_openapi/docs/ModelRegistryServiceApi.md#create_model_artifact) | **POST** /api/model_registry/v1alpha3/model_artifacts | Create a ModelArtifact
*ModelRegistryServiceApi* | [**create_model_version**](mr_openapi/docs/ModelRegistryServiceApi.md#create_model_version) | **POST** /api/model_registry/v1alpha3/model_versions | Create a ModelVersion
*ModelRegistryServiceApi* | [**create_registered_model**](mr_openapi/docs/ModelRegistryServiceApi.md#create_registered_model) | **POST** /api/model_registry/v1alpha3/registered_models | Create a RegisteredModel
*ModelRegistryServiceApi* | [**create_registered_model_version**](mr_openapi/docs/ModelRegistryServiceApi.md#create_registered_model_version) | **POST** /api/model_registry/v1alpha3/registered_models/{registeredmodelId}/versions | Create a ModelVersion in RegisteredModel
*ModelRegistryServiceApi* | [**create_serving_environment**](mr_openapi/docs/ModelRegistryServiceApi.md#create_serving_environment) | **POST** /api/model_registry/v1alpha3/serving_environments | Create a ServingEnvironment
*ModelRegistryServiceApi* | [**find_inference_service**](mr_openapi/docs/ModelRegistryServiceApi.md#find_inference_service) | **GET** /api/model_registry/v1alpha3/inference_service | Get an InferenceServices that matches search parameters.
*ModelRegistryServiceApi* | [**find_model_artifact**](mr_openapi/docs/ModelRegistryServiceApi.md#find_model_artifact) | **GET** /api/model_registry/v1alpha3/model_artifact | Get a ModelArtifact that matches search parameters.
*ModelRegistryServiceApi* | [**find_model_version**](mr_openapi/docs/ModelRegistryServiceApi.md#find_model_version) | **GET** /api/model_registry/v1alpha3/model_version | Get a ModelVersion that matches search parameters.
*ModelRegistryServiceApi* | [**find_registered_model**](mr_openapi/docs/ModelRegistryServiceApi.md#find_registered_model) | **GET** /api/model_registry/v1alpha3/registered_model | Get a RegisteredModel that matches search parameters.
*ModelRegistryServiceApi* | [**find_serving_environment**](mr_openapi/docs/ModelRegistryServiceApi.md#find_serving_environment) | **GET** /api/model_registry/v1alpha3/serving_environment | Find ServingEnvironment
*ModelRegistryServiceApi* | [**get_environment_inference_services**](mr_openapi/docs/ModelRegistryServiceApi.md#get_environment_inference_services) | **GET** /api/model_registry/v1alpha3/serving_environments/{servingenvironmentId}/inference_services | List All ServingEnvironment&#39;s InferenceServices
*ModelRegistryServiceApi* | [**get_inference_service**](mr_openapi/docs/ModelRegistryServiceApi.md#get_inference_service) | **GET** /api/model_registry/v1alpha3/inference_services/{inferenceserviceId} | Get a InferenceService
*ModelRegistryServiceApi* | [**get_inference_service_model**](mr_openapi/docs/ModelRegistryServiceApi.md#get_inference_service_model) | **GET** /api/model_registry/v1alpha3/inference_services/{inferenceserviceId}/model | Get InferenceService&#39;s RegisteredModel
*ModelRegistryServiceApi* | [**get_inference_service_serves**](mr_openapi/docs/ModelRegistryServiceApi.md#get_inference_service_serves) | **GET** /api/model_registry/v1alpha3/inference_services/{inferenceserviceId}/serves | List All InferenceService&#39;s ServeModel actions
*ModelRegistryServiceApi* | [**get_inference_service_version**](mr_openapi/docs/ModelRegistryServiceApi.md#get_inference_service_version) | **GET** /api/model_registry/v1alpha3/inference_services/{inferenceserviceId}/version | Get InferenceService&#39;s ModelVersion
*ModelRegistryServiceApi* | [**get_inference_services**](mr_openapi/docs/ModelRegistryServiceApi.md#get_inference_services) | **GET** /api/model_registry/v1alpha3/inference_services | List All InferenceServices
*ModelRegistryServiceApi* | [**get_model_artifact**](mr_openapi/docs/ModelRegistryServiceApi.md#get_model_artifact) | **GET** /api/model_registry/v1alpha3/model_artifacts/{modelartifactId} | Get a ModelArtifact
*ModelRegistryServiceApi* | [**get_model_artifacts**](mr_openapi/docs/ModelRegistryServiceApi.md#get_model_artifacts) | **GET** /api/model_registry/v1alpha3/model_artifacts | List All ModelArtifacts
*ModelRegistryServiceApi* | [**get_model_version**](mr_openapi/docs/ModelRegistryServiceApi.md#get_model_version) | **GET** /api/model_registry/v1alpha3/model_versions/{modelversionId} | Get a ModelVersion
*ModelRegistryServiceApi* | [**get_model_version_artifacts**](mr_openapi/docs/ModelRegistryServiceApi.md#get_model_version_artifacts) | **GET** /api/model_registry/v1alpha3/model_versions/{modelversionId}/artifacts | List all artifacts associated with the &#x60;ModelVersion&#x60;
*ModelRegistryServiceApi* | [**get_model_versions**](mr_openapi/docs/ModelRegistryServiceApi.md#get_model_versions) | **GET** /api/model_registry/v1alpha3/model_versions | List All ModelVersions
*ModelRegistryServiceApi* | [**get_registered_model**](mr_openapi/docs/ModelRegistryServiceApi.md#get_registered_model) | **GET** /api/model_registry/v1alpha3/registered_models/{registeredmodelId} | Get a RegisteredModel
*ModelRegistryServiceApi* | [**get_registered_model_versions**](mr_openapi/docs/ModelRegistryServiceApi.md#get_registered_model_versions) | **GET** /api/model_registry/v1alpha3/registered_models/{registeredmodelId}/versions | List All RegisteredModel&#39;s ModelVersions
*ModelRegistryServiceApi* | [**get_registered_models**](mr_openapi/docs/ModelRegistryServiceApi.md#get_registered_models) | **GET** /api/model_registry/v1alpha3/registered_models | List All RegisteredModels
*ModelRegistryServiceApi* | [**get_serving_environment**](mr_openapi/docs/ModelRegistryServiceApi.md#get_serving_environment) | **GET** /api/model_registry/v1alpha3/serving_environments/{servingenvironmentId} | Get a ServingEnvironment
*ModelRegistryServiceApi* | [**get_serving_environments**](mr_openapi/docs/ModelRegistryServiceApi.md#get_serving_environments) | **GET** /api/model_registry/v1alpha3/serving_environments | List All ServingEnvironments
*ModelRegistryServiceApi* | [**update_inference_service**](mr_openapi/docs/ModelRegistryServiceApi.md#update_inference_service) | **PATCH** /api/model_registry/v1alpha3/inference_services/{inferenceserviceId} | Update a InferenceService
*ModelRegistryServiceApi* | [**update_model_artifact**](mr_openapi/docs/ModelRegistryServiceApi.md#update_model_artifact) | **PATCH** /api/model_registry/v1alpha3/model_artifacts/{modelartifactId} | Update a ModelArtifact
*ModelRegistryServiceApi* | [**update_model_version**](mr_openapi/docs/ModelRegistryServiceApi.md#update_model_version) | **PATCH** /api/model_registry/v1alpha3/model_versions/{modelversionId} | Update a ModelVersion
*ModelRegistryServiceApi* | [**update_registered_model**](mr_openapi/docs/ModelRegistryServiceApi.md#update_registered_model) | **PATCH** /api/model_registry/v1alpha3/registered_models/{registeredmodelId} | Update a RegisteredModel
*ModelRegistryServiceApi* | [**update_serving_environment**](mr_openapi/docs/ModelRegistryServiceApi.md#update_serving_environment) | **PATCH** /api/model_registry/v1alpha3/serving_environments/{servingenvironmentId} | Update a ServingEnvironment
*ModelRegistryServiceApi* | [**upsert_model_version_artifact**](mr_openapi/docs/ModelRegistryServiceApi.md#upsert_model_version_artifact) | **POST** /api/model_registry/v1alpha3/model_versions/{modelversionId}/artifacts | Upsert an Artifact in a ModelVersion


## Documentation For Models

 - [Artifact](mr_openapi/docs/Artifact.md)
 - [ArtifactList](mr_openapi/docs/ArtifactList.md)
 - [ArtifactState](mr_openapi/docs/ArtifactState.md)
 - [BaseArtifact](mr_openapi/docs/BaseArtifact.md)
 - [BaseArtifactCreate](mr_openapi/docs/BaseArtifactCreate.md)
 - [BaseArtifactUpdate](mr_openapi/docs/BaseArtifactUpdate.md)
 - [BaseExecution](mr_openapi/docs/BaseExecution.md)
 - [BaseExecutionCreate](mr_openapi/docs/BaseExecutionCreate.md)
 - [BaseExecutionUpdate](mr_openapi/docs/BaseExecutionUpdate.md)
 - [BaseResource](mr_openapi/docs/BaseResource.md)
 - [BaseResourceCreate](mr_openapi/docs/BaseResourceCreate.md)
 - [BaseResourceList](mr_openapi/docs/BaseResourceList.md)
 - [BaseResourceUpdate](mr_openapi/docs/BaseResourceUpdate.md)
 - [DocArtifact](mr_openapi/docs/DocArtifact.md)
 - [Error](mr_openapi/docs/Error.md)
 - [ExecutionState](mr_openapi/docs/ExecutionState.md)
 - [InferenceService](mr_openapi/docs/InferenceService.md)
 - [InferenceServiceCreate](mr_openapi/docs/InferenceServiceCreate.md)
 - [InferenceServiceList](mr_openapi/docs/InferenceServiceList.md)
 - [InferenceServiceState](mr_openapi/docs/InferenceServiceState.md)
 - [InferenceServiceUpdate](mr_openapi/docs/InferenceServiceUpdate.md)
 - [MetadataBoolValue](mr_openapi/docs/MetadataBoolValue.md)
 - [MetadataDoubleValue](mr_openapi/docs/MetadataDoubleValue.md)
 - [MetadataIntValue](mr_openapi/docs/MetadataIntValue.md)
 - [MetadataProtoValue](mr_openapi/docs/MetadataProtoValue.md)
 - [MetadataStringValue](mr_openapi/docs/MetadataStringValue.md)
 - [MetadataStructValue](mr_openapi/docs/MetadataStructValue.md)
 - [MetadataValue](mr_openapi/docs/MetadataValue.md)
 - [ModelArtifact](mr_openapi/docs/ModelArtifact.md)
 - [ModelArtifactCreate](mr_openapi/docs/ModelArtifactCreate.md)
 - [ModelArtifactList](mr_openapi/docs/ModelArtifactList.md)
 - [ModelArtifactUpdate](mr_openapi/docs/ModelArtifactUpdate.md)
 - [ModelVersion](mr_openapi/docs/ModelVersion.md)
 - [ModelVersionCreate](mr_openapi/docs/ModelVersionCreate.md)
 - [ModelVersionList](mr_openapi/docs/ModelVersionList.md)
 - [ModelVersionState](mr_openapi/docs/ModelVersionState.md)
 - [ModelVersionUpdate](mr_openapi/docs/ModelVersionUpdate.md)
 - [OrderByField](mr_openapi/docs/OrderByField.md)
 - [RegisteredModel](mr_openapi/docs/RegisteredModel.md)
 - [RegisteredModelCreate](mr_openapi/docs/RegisteredModelCreate.md)
 - [RegisteredModelList](mr_openapi/docs/RegisteredModelList.md)
 - [RegisteredModelState](mr_openapi/docs/RegisteredModelState.md)
 - [RegisteredModelUpdate](mr_openapi/docs/RegisteredModelUpdate.md)
 - [ServeModel](mr_openapi/docs/ServeModel.md)
 - [ServeModelCreate](mr_openapi/docs/ServeModelCreate.md)
 - [ServeModelList](mr_openapi/docs/ServeModelList.md)
 - [ServeModelUpdate](mr_openapi/docs/ServeModelUpdate.md)
 - [ServingEnvironment](mr_openapi/docs/ServingEnvironment.md)
 - [ServingEnvironmentCreate](mr_openapi/docs/ServingEnvironmentCreate.md)
 - [ServingEnvironmentList](mr_openapi/docs/ServingEnvironmentList.md)
 - [ServingEnvironmentUpdate](mr_openapi/docs/ServingEnvironmentUpdate.md)
 - [SortOrder](mr_openapi/docs/SortOrder.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="Bearer"></a>
### Bearer

- **Type**: Bearer authentication (JWT)


## Author




